History
=======

Beta (2014-10-08)
---------------------
* Massively updated! Compatability with previous versions very broken.
* Software retrofitted to be much more flexible to support a wider range of problems.

0.0.2 (2014-08-18)
---------------------

* Remove incompatible use of `print`

0.0.1 (2014-08-18)
---------------------

* Initial package
